bayespy.nodes.GaussianWishart
=============================

.. currentmodule:: bayespy.nodes

.. autoclass:: GaussianWishart

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~GaussianWishart.__init__
      ~GaussianWishart.add_plate_axis
      ~GaussianWishart.broadcasting_multiplier
      ~GaussianWishart.delete
      ~GaussianWishart.get_gradient
      ~GaussianWishart.get_mask
      ~GaussianWishart.get_moments
      ~GaussianWishart.get_parameters
      ~GaussianWishart.get_riemannian_gradient
      ~GaussianWishart.get_shape
      ~GaussianWishart.has_plotter
      ~GaussianWishart.initialize_from_parameters
      ~GaussianWishart.initialize_from_prior
      ~GaussianWishart.initialize_from_random
      ~GaussianWishart.initialize_from_value
      ~GaussianWishart.load
      ~GaussianWishart.logpdf
      ~GaussianWishart.lower_bound_contribution
      ~GaussianWishart.lowerbound
      ~GaussianWishart.move_plates
      ~GaussianWishart.observe
      ~GaussianWishart.pdf
      ~GaussianWishart.plot
      ~GaussianWishart.random
      ~GaussianWishart.save
      ~GaussianWishart.set_parameters
      ~GaussianWishart.set_plotter
      ~GaussianWishart.show
      ~GaussianWishart.unobserve
      ~GaussianWishart.update
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~GaussianWishart.dims
      ~GaussianWishart.plates
      ~GaussianWishart.plates_multiplier
   
   